# OrzMC

A tool for deploying minecraft client and server

Only supports Python >=2.7, <4

Requires Java Runtime Environment to be configured!

# Supported Minecraft Client Version

- supports all versions of client

- you should make sure the version of the minecraft server that you will connect to is the same as that of the client.

- This Program has been uploaded into PyPI

# Supported Operating System

- mainly for MacOS.
- Maybe can run on windows, as a backup schema.

# Usage

**You should have a jre runtime on you device**

## Run Client

`orzmc -h` to check the help info
```
$ pip install orzmc
$ orzmc
```

## Deploy Server

`orzmcs -h` to check the help info

```
$ pip install orzmc
$ orzmcs
```

The game resources are saved under user's home directory, and named `.minecraft`

# Tips

This is not a game for one player, so you should invit someone you like to make you guys own beautiful world!!!

# Video Introduction

https://youtu.be/gx-JeoW2K5I


# TODO List

- [x] add Spigot Server deploy option
- [x] add a homepage for this project
- [ ] refine the project script for readable

# Reference

[SpigotMC](https://www.spigotmc.org/)
